@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP12;
 use vars '$VERSION';
-$VERSION = '0.71';
+$VERSION = '0.72';
 use base 'XML::Compile::SOAP';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -45,10 +45,7 @@ sub init($)
 
     my $rpc = $self->{rpc} = $args->{rpc} || SOAP12RPC;
 
-    my $schemas = $self->schemas;
-    $schemas->importDefinitions($env);
-    $schemas->importDefinitions($enc);
-    $schemas->importDefinitions($rpc);
+    $self->schemas->importDefinitions( [$env, $enc, $rpc] );
     $self;
 }
 
